Contributing
============

Contributions welcome 

- If tests pass and and the request is logical, it should get accepted.  
- Please squash/fixup your commits into logical units.
- Pep8 is encouraged (for the code you write).

Testing
=======

Clone the repo.

```
git clone https://github.com/sky-shiny/smolder.git
cd smolder
```

Create a new virtualenv.

```mkvirtualenv smolder```

Install smolder from source (from the project root) to get the relevant dependencies:

```pip install . --upgrade```

Run the tests.

```nosetests```
